@@ -47,9 +47,10 @@ class ExecutionMatch:
     dedup_string: str
     dedup_period_mins: int
     event: Dict[str, Any]
-    # one of these will be set
+    # some of these will be set
     event_id: Optional[str] = None
     replay_id: Optional[str] = None
+    event_timestamp: Optional[str] = None # Use ISO 8601! %Y-%m-%dT%H:%M:%S.%f%z
     # optional dynamic fields
     severity: Optional[str] = None
     alert_context: Optional[str] = None
